% ainvmel - arrow to warp mel scale spectrum to linear freq spectrum
%
% ainvmel :: 
%    N:natural ~'block size of original audio frames',
%    nonneg    ~'audio sampling frequency in Hz',
%    [[1,2]]   ~'frequency limits in Hz',
%    L:natural ~'number of bands in mel spectrum'
% -> arrow( {[[L]]}, {[[dftbins(N)]]}, empty).

function o=ainvmel(N,fs,flim,L)
	o=amult(tri_filterbank_aa(melspace(flim(1),min(flim(2),fs/2),L+2),binmap(0,fs/2,dftbins(N)))');
end
